<!--
  Transforms openmath cd plot1 to Javascript syntax.
-->
<xsl:transform version='1.0'
  xmlns:xsl='http://www.w3.org/1999/XSL/Transform'
  xmlns:om="http://www.openmath.org/OpenMath"
>

  <!-- plot1.configuration -->
  <xsl:template 
    match='om:OMA[*[1][self::om:OMS[@cd="plot1" and @name="configuration"]]]'
  >
    <xsl:variable name='xmin'>
      <xsl:choose>
        <xsl:when test='om:OMA[om:OMS[@cd="plot1" and @name="viewport"]]'>
          <xsl:value-of select='om:OMA[om:OMS[@cd="plot1" and @name="viewport"]]/*[2]/*[2]'/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:copy-of select='$viewport.xmin'/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:variable name='xmax'>
      <xsl:choose>
        <xsl:when test='om:OMA[om:OMS[@cd="plot1" and @name="viewport"]]'>
          <xsl:value-of select='om:OMA[om:OMS[@cd="plot1" and @name="viewport"]]/*[2]/*[3]'/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:copy-of select='$viewport.xmax'/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:variable name='ymin'>
      <xsl:choose>
        <xsl:when test='om:OMA[om:OMS[@cd="plot1" and @name="viewport"]]'>
          <xsl:value-of select='om:OMA[om:OMS[@cd="plot1" and @name="viewport"]]/*[3]/*[2]'/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:copy-of select='$viewport.ymin'/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:variable name='ymax'>
      <xsl:choose>
        <xsl:when test='om:OMA[om:OMS[@cd="plot1" and @name="viewport"]]'>
          <xsl:value-of select='om:OMA[om:OMS[@cd="plot1" and @name="viewport"]]/*[3]/*[3]'/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:copy-of select='$viewport.ymax'/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>


    <xsl:text> /* constructing brd using board_id */ </xsl:text>
    <xsl:text>var brd = JXG.JSXGraph.initBoard( board_id , {</xsl:text>
    <xsl:text>axis:true, showCopyright:false, showNavigation:false, </xsl:text>

    <xsl:text>boundingbox: [ </xsl:text>
    <xsl:value-of select='$xmin'/>
    <xsl:text> , </xsl:text>
    <xsl:value-of select='$ymax'/>
    <xsl:text> , </xsl:text>
    <xsl:value-of select='$xmax'/>
    <xsl:text> , </xsl:text>
    <xsl:value-of select='$ymin'/>
    <xsl:text> ] </xsl:text>

    <xsl:text> } );</xsl:text>

    <xsl:apply-templates>
      <xsl:with-param name='xmin' select='$xmin'/>
      <xsl:with-param name='xmax' select='$xmax'/>
    </xsl:apply-templates>
  </xsl:template>
  
  <xsl:template 
    match='om:OMA[*[1][self::om:OMS[@cd="plot1" and @name="functionplot"]]]'
  >
    <xsl:param name='xmin' select='$viewport.xmin'/>
    <xsl:param name='xmax' select='$viewport.xmax'/>

    <xsl:text>brd.create('functiongraph', [</xsl:text>
    <xsl:apply-templates select='*[2]'/>
    <xsl:text> , </xsl:text>
    <xsl:choose>
      <xsl:when test='om:OMA[*[1][self::om:OMS[@cd="plot1" and @name="domain"]] and 
          *[2][self::om:OMA[om:OMS[@cd="interval1" and @name="interval"]]]]'>
        <xsl:value-of select='om:OMA[*[1][self::om:OMS[@cd="plot1" and @name="domain"]]]/*[2]/*[2]'/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select='$xmin'/>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:text> , </xsl:text>
    <xsl:choose>
      <xsl:when test='om:OMA[*[1][self::om:OMS[@cd="plot1" and @name="domain"]] and 
          *[2][self::om:OMA[om:OMS[@cd="interval1" and @name="interval"]]]]'>
        <xsl:value-of select='om:OMA[*[1][self::om:OMS[@cd="plot1" and @name="domain"]]]/*[2]/*[3]'/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select='$xmax'/>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:text>]</xsl:text>
    <xsl:if test='om:OMA[*[1][self::om:OMS[@cd="plot1" and @name="label"]]]'>
      <xsl:text>, { withLabel : true, name: "</xsl:text>
      <xsl:value-of select='om:OMA[*[1][self::om:OMS[@cd="plot1" and @name="label"]]]/*[2]'/>
      <xsl:text>" } </xsl:text>
    </xsl:if>
    <xsl:text>);</xsl:text>
  </xsl:template>

  <!-- plot1.viewport: only show in options mode-->
  <xsl:template 
    match='om:OMA[*[1][self::om:OMS[@cd="plot1" and @name="viewport"]]]'
  />
</xsl:transform>
